/*
 * Copyright (C) 2010 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef WebSoupRequestManagerMessages_h
#define WebSoupRequestManagerMessages_h

#include "Arguments.h"
#include "MessageEncoder.h"
#include "StringReference.h"

namespace IPC {
    class DataReference;
}

namespace WTF {
    class String;
}

namespace WebCore {
    class ResourceError;
}

namespace Messages {
namespace WebSoupRequestManager {

static inline IPC::StringReference messageReceiverName()
{
    return IPC::StringReference("WebSoupRequestManager");
}

class RegisterURIScheme {
public:
    typedef std::tuple<String> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("RegisterURIScheme"); }
    static const bool isSync = false;

    explicit RegisterURIScheme(const String& uriScheme)
        : m_arguments(uriScheme)
    {
    }

    const std::tuple<const String&> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const String&> m_arguments;
};

class DidHandleURIRequest {
public:
    typedef std::tuple<IPC::DataReference, uint64_t, String, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidHandleURIRequest"); }
    static const bool isSync = false;

    DidHandleURIRequest(const IPC::DataReference& requestData, uint64_t contentLength, const String& mimeType, uint64_t requestID)
        : m_arguments(requestData, contentLength, mimeType, requestID)
    {
    }

    const std::tuple<const IPC::DataReference&, uint64_t, const String&, uint64_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const IPC::DataReference&, uint64_t, const String&, uint64_t> m_arguments;
};

class DidReceiveURIRequestData {
public:
    typedef std::tuple<IPC::DataReference, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidReceiveURIRequestData"); }
    static const bool isSync = false;

    DidReceiveURIRequestData(const IPC::DataReference& requestData, uint64_t requestID)
        : m_arguments(requestData, requestID)
    {
    }

    const std::tuple<const IPC::DataReference&, uint64_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const IPC::DataReference&, uint64_t> m_arguments;
};

class DidFailURIRequest {
public:
    typedef std::tuple<WebCore::ResourceError, uint64_t> DecodeType;

    static IPC::StringReference receiverName() { return messageReceiverName(); }
    static IPC::StringReference name() { return IPC::StringReference("DidFailURIRequest"); }
    static const bool isSync = false;

    DidFailURIRequest(const WebCore::ResourceError& error, uint64_t requestID)
        : m_arguments(error, requestID)
    {
    }

    const std::tuple<const WebCore::ResourceError&, uint64_t> arguments() const
    {
        return m_arguments;
    }

private:
    std::tuple<const WebCore::ResourceError&, uint64_t> m_arguments;
};

} // namespace WebSoupRequestManager
} // namespace Messages

#endif // WebSoupRequestManagerMessages_h
